← back to Dw Marketing Reels
Themeable reels + Phillipe Romano cork reel (env-driven copy/caption/slug + vendor/title/dedupe fetch filters)
78da8fdd80493eae7fb47754f08148bc6c41a6d3 · 2026-07-12 23:09:21 -0700 · Steve Abrams
Files touched
M data/new-arrivals.jsonM data/reels.jsonM scripts/build-reel.mjsM scripts/fetch-new-arrivals.mjs
Diff
commit 78da8fdd80493eae7fb47754f08148bc6c41a6d3
Author: Steve Abrams <steve@designerwallcoverings.com>
Date: Sun Jul 12 23:09:21 2026 -0700
Themeable reels + Phillipe Romano cork reel (env-driven copy/caption/slug + vendor/title/dedupe fetch filters)
---
data/new-arrivals.json | 1157 +++++++++++++++++++++++++++-------------
data/reels.json | 39 ++
scripts/build-reel.mjs | 39 +-
scripts/fetch-new-arrivals.mjs | 27 +-
4 files changed, 888 insertions(+), 374 deletions(-)
diff --git a/data/new-arrivals.json b/data/new-arrivals.json
index fec604b..7c684cf 100644
--- a/data/new-arrivals.json
+++ b/data/new-arrivals.json
@@ -1,367 +1,802 @@
{
- "source": "https://designerwallcoverings.com/collections/new-arrivals",
- "fetched_at": "2026-07-12T17:14:36.543Z",
- "count": 24,
+ "source": "https://designerwallcoverings.com/collections/cork",
+ "fetched_at": "2026-07-13T06:06:24.135Z",
+ "count": 53,
"items": [
{
- "id": 7882783621171,
- "handle": "katamari-pewter-dwtt-74068",
- "title": "Katamari, Pewter Wallcoverings | Thibaut",
- "pattern": "Katamari",
- "color": "Pewter",
- "vendor": "Thibaut",
- "product_type": "Wallcovering",
- "image": "https://cdn.shopify.com/s/files/1/0015/4117/7456/files/T34074_97ea7996-88e6-40bb-8df7-39d8ec10245c.jpg?v=1783874418",
- "image_hi": "https://cdn.shopify.com/s/files/1/0015/4117/7456/files/T34074_97ea7996-88e6-40bb-8df7-39d8ec10245c_1200x.jpg?v=1783874418",
- "price": "130.32",
- "url": "https://designerwallcoverings.com/products/katamari-pewter-dwtt-74068",
- "created_at": "2026-07-12T09:40:15-07:00",
- "published_at": "2026-07-12T09:40:17-07:00"
- },
- {
- "id": 7882783588403,
- "handle": "tenaya-beige-dwtt-74067",
- "title": "Tenaya, Beige Wallcoverings | Thibaut",
- "pattern": "Tenaya",
- "color": "Beige",
- "vendor": "Thibaut",
- "product_type": "Wallcovering",
- "image": "https://cdn.shopify.com/s/files/1/0015/4117/7456/files/T34072.jpg?v=1783874414",
- "image_hi": "https://cdn.shopify.com/s/files/1/0015/4117/7456/files/T34072_1200x.jpg?v=1783874414",
- "price": "141.72",
- "url": "https://designerwallcoverings.com/products/tenaya-beige-dwtt-74067",
- "created_at": "2026-07-12T09:40:12-07:00",
- "published_at": "2026-07-12T09:40:13-07:00"
- },
- {
- "id": 7882783555635,
- "handle": "katamari-dark-gold-dwtt-74066",
- "title": "Katamari, Dark Gold Wallcoverings | Thibaut",
- "pattern": "Katamari",
- "color": "Dark Gold",
- "vendor": "Thibaut",
- "product_type": "Wallcovering",
- "image": "https://cdn.shopify.com/s/files/1/0015/4117/7456/files/T34073_f3da0951-bdd3-4e1f-ae08-1b47721a0f6e.jpg?v=1783874411",
- "image_hi": "https://cdn.shopify.com/s/files/1/0015/4117/7456/files/T34073_f3da0951-bdd3-4e1f-ae08-1b47721a0f6e_1200x.jpg?v=1783874411",
- "price": "130.32",
- "url": "https://designerwallcoverings.com/products/katamari-dark-gold-dwtt-74066",
- "created_at": "2026-07-12T09:40:07-07:00",
- "published_at": "2026-07-12T09:40:09-07:00"
- },
- {
- "id": 7882775527475,
- "handle": "tenaya-cream-dwtt-74065",
- "title": "Tenaya, Cream Wallcoverings | Thibaut",
- "pattern": "Tenaya",
- "color": "Cream",
- "vendor": "Thibaut",
- "product_type": "Wallcovering",
- "image": "https://cdn.shopify.com/s/files/1/0015/4117/7456/files/T34071.jpg?v=1783870817",
- "image_hi": "https://cdn.shopify.com/s/files/1/0015/4117/7456/files/T34071_1200x.jpg?v=1783870817",
- "price": "141.72",
- "url": "https://designerwallcoverings.com/products/tenaya-cream-dwtt-74065",
- "created_at": "2026-07-12T08:40:15-07:00",
- "published_at": "2026-07-12T08:40:16-07:00"
- },
- {
- "id": 7882775494707,
- "handle": "tenaya-spa-blue-dwtt-74064",
- "title": "Tenaya, Spa Blue Wallcoverings | Thibaut",
- "pattern": "Tenaya",
- "color": "Spa Blue",
- "vendor": "Thibaut",
- "product_type": "Wallcovering",
- "image": "https://cdn.shopify.com/s/files/1/0015/4117/7456/files/T34070_81f41471-3b8c-4d53-9e8f-2f42ecdeec4c.jpg?v=1783870815",
- "image_hi": "https://cdn.shopify.com/s/files/1/0015/4117/7456/files/T34070_81f41471-3b8c-4d53-9e8f-2f42ecdeec4c_1200x.jpg?v=1783870815",
- "price": "141.72",
- "url": "https://designerwallcoverings.com/products/tenaya-spa-blue-dwtt-74064",
- "created_at": "2026-07-12T08:40:11-07:00",
- "published_at": "2026-07-12T08:40:12-07:00"
- },
- {
- "id": 7882775429171,
- "handle": "tenaya-sage-dwtt-74063",
- "title": "Tenaya, Sage Wallcoverings | Thibaut",
- "pattern": "Tenaya",
- "color": "Sage",
- "vendor": "Thibaut",
- "product_type": "Wallcovering",
- "image": "https://cdn.shopify.com/s/files/1/0015/4117/7456/files/T34069_cbc48cb4-4dee-41ff-8429-92859c80b6fc.jpg?v=1783870810",
- "image_hi": "https://cdn.shopify.com/s/files/1/0015/4117/7456/files/T34069_cbc48cb4-4dee-41ff-8429-92859c80b6fc_1200x.jpg?v=1783870810",
- "price": "141.72",
- "url": "https://designerwallcoverings.com/products/tenaya-sage-dwtt-74063",
- "created_at": "2026-07-12T08:40:07-07:00",
- "published_at": "2026-07-12T08:40:09-07:00"
- },
- {
- "id": 7882766319667,
- "handle": "tenaya-fog-dwtt-74062",
- "title": "Tenaya, Fog Wallcoverings | Thibaut",
- "pattern": "Tenaya",
- "color": "Fog",
- "vendor": "Thibaut",
- "product_type": "Wallcovering",
- "image": "https://cdn.shopify.com/s/files/1/0015/4117/7456/files/T34068_07acc6ed-ec25-47bf-b2d8-b1b4e4987425.jpg?v=1783867217",
- "image_hi": "https://cdn.shopify.com/s/files/1/0015/4117/7456/files/T34068_07acc6ed-ec25-47bf-b2d8-b1b4e4987425_1200x.jpg?v=1783867217",
- "price": "141.72",
- "url": "https://designerwallcoverings.com/products/tenaya-fog-dwtt-74062",
- "created_at": "2026-07-12T07:40:15-07:00",
- "published_at": "2026-07-12T07:40:16-07:00"
- },
- {
- "id": 7882766286899,
- "handle": "tenaya-dusk-dwtt-74061",
- "title": "Tenaya, Dusk Wallcoverings | Thibaut",
- "pattern": "Tenaya",
- "color": "Dusk",
- "vendor": "Thibaut",
- "product_type": "Wallcovering",
- "image": "https://cdn.shopify.com/s/files/1/0015/4117/7456/files/T34066.jpg?v=1783867214",
- "image_hi": "https://cdn.shopify.com/s/files/1/0015/4117/7456/files/T34066_1200x.jpg?v=1783867214",
- "price": "141.72",
- "url": "https://designerwallcoverings.com/products/tenaya-dusk-dwtt-74061",
- "created_at": "2026-07-12T07:40:11-07:00",
- "published_at": "2026-07-12T07:40:13-07:00"
- },
- {
- "id": 7882766221363,
- "handle": "tenaya-mineral-dwtt-74060",
- "title": "Tenaya, Mineral Wallcoverings | Thibaut",
- "pattern": "Tenaya",
- "color": "Mineral",
- "vendor": "Thibaut",
- "product_type": "Wallcovering",
- "image": "https://cdn.shopify.com/s/files/1/0015/4117/7456/files/T34067_5ce89ab8-b1e2-41d1-aeeb-b565f9869c3a.jpg?v=1783867210",
- "image_hi": "https://cdn.shopify.com/s/files/1/0015/4117/7456/files/T34067_5ce89ab8-b1e2-41d1-aeeb-b565f9869c3a_1200x.jpg?v=1783867210",
- "price": "141.72",
- "url": "https://designerwallcoverings.com/products/tenaya-mineral-dwtt-74060",
- "created_at": "2026-07-12T07:40:07-07:00",
- "published_at": "2026-07-12T07:40:09-07:00"
- },
- {
- "id": 7882736992307,
- "handle": "linen-weave-white-dwtt-74059",
- "title": "Linen Weave, White Wallcoverings | Thibaut",
- "pattern": "Linen Weave",
- "color": "White",
- "vendor": "Thibaut",
- "product_type": "Wallcovering",
- "image": "https://cdn.shopify.com/s/files/1/0015/4117/7456/files/T34057.jpg?v=1783863619",
- "image_hi": "https://cdn.shopify.com/s/files/1/0015/4117/7456/files/T34057_1200x.jpg?v=1783863619",
- "price": "141.72",
- "url": "https://designerwallcoverings.com/products/linen-weave-white-dwtt-74059",
- "created_at": "2026-07-12T06:40:16-07:00",
- "published_at": "2026-07-12T06:40:18-07:00"
- },
- {
- "id": 7882736926771,
- "handle": "linen-weave-sand-dwtt-74058",
- "title": "Linen Weave, Sand Wallcoverings | Thibaut",
- "pattern": "Linen Weave",
- "color": "Sand",
- "vendor": "Thibaut",
- "product_type": "Wallcovering",
- "image": "https://cdn.shopify.com/s/files/1/0015/4117/7456/files/T34056.jpg?v=1783863615",
- "image_hi": "https://cdn.shopify.com/s/files/1/0015/4117/7456/files/T34056_1200x.jpg?v=1783863615",
- "price": "141.72",
- "url": "https://designerwallcoverings.com/products/linen-weave-sand-dwtt-74058",
- "created_at": "2026-07-12T06:40:12-07:00",
- "published_at": "2026-07-12T06:40:14-07:00"
- },
- {
- "id": 7882736894003,
- "handle": "linen-weave-off-white-dwtt-74057",
- "title": "Linen Weave, Off White Wallcoverings | Thibaut",
- "pattern": "Linen Weave",
- "color": "Off White",
- "vendor": "Thibaut",
- "product_type": "Wallcovering",
- "image": "https://cdn.shopify.com/s/files/1/0015/4117/7456/files/T34055_36e39e93-f3c6-4302-8221-3fff084c51f7.jpg?v=1783863610",
- "image_hi": "https://cdn.shopify.com/s/files/1/0015/4117/7456/files/T34055_36e39e93-f3c6-4302-8221-3fff084c51f7_1200x.jpg?v=1783863610",
- "price": "141.72",
- "url": "https://designerwallcoverings.com/products/linen-weave-off-white-dwtt-74057",
- "created_at": "2026-07-12T06:40:07-07:00",
- "published_at": "2026-07-12T06:40:10-07:00"
- },
- {
- "id": 7882719592499,
- "handle": "linen-weave-tan-dwtt-74056",
- "title": "Linen Weave, Tan Wallcoverings | Thibaut",
- "pattern": "Linen Weave",
- "color": "Tan",
- "vendor": "Thibaut",
- "product_type": "Wallcovering",
- "image": "https://cdn.shopify.com/s/files/1/0015/4117/7456/files/T34053.jpg?v=1783860018",
- "image_hi": "https://cdn.shopify.com/s/files/1/0015/4117/7456/files/T34053_1200x.jpg?v=1783860018",
- "price": "141.72",
- "url": "https://designerwallcoverings.com/products/linen-weave-tan-dwtt-74056",
- "created_at": "2026-07-12T05:40:16-07:00",
- "published_at": "2026-07-12T05:40:17-07:00"
- },
- {
- "id": 7882719330355,
- "handle": "linen-weave-caramel-dwtt-74055",
- "title": "Linen Weave, Caramel Wallcoverings | Thibaut",
- "pattern": "Linen Weave",
- "color": "Caramel",
- "vendor": "Thibaut",
- "product_type": "Wallcovering",
- "image": "https://cdn.shopify.com/s/files/1/0015/4117/7456/files/T34054_28c6d832-5378-4895-84c6-cbbf10abff30.jpg?v=1783860016",
- "image_hi": "https://cdn.shopify.com/s/files/1/0015/4117/7456/files/T34054_28c6d832-5378-4895-84c6-cbbf10abff30_1200x.jpg?v=1783860016",
- "price": "141.72",
- "url": "https://designerwallcoverings.com/products/linen-weave-caramel-dwtt-74055",
- "created_at": "2026-07-12T05:40:12-07:00",
- "published_at": "2026-07-12T05:40:13-07:00"
- },
- {
- "id": 7882719035443,
- "handle": "linen-weave-dark-grey-dwtt-74054",
- "title": "Linen Weave, Dark Grey Wallcoverings | Thibaut",
- "pattern": "Linen Weave",
- "color": "Dark Grey",
- "vendor": "Thibaut",
- "product_type": "Wallcovering",
- "image": "https://cdn.shopify.com/s/files/1/0015/4117/7456/files/T34052.jpg?v=1783860010",
- "image_hi": "https://cdn.shopify.com/s/files/1/0015/4117/7456/files/T34052_1200x.jpg?v=1783860010",
- "price": "141.72",
- "url": "https://designerwallcoverings.com/products/linen-weave-dark-grey-dwtt-74054",
- "created_at": "2026-07-12T05:40:07-07:00",
- "published_at": "2026-07-12T05:40:10-07:00"
- },
- {
- "id": 7882595565619,
- "handle": "linen-weave-black-dwtt-74053",
- "title": "Linen Weave, Black Wallcoverings | Thibaut",
- "pattern": "Linen Weave",
- "color": "Black",
- "vendor": "Thibaut",
- "product_type": "Wallcovering",
- "image": "https://cdn.shopify.com/s/files/1/0015/4117/7456/files/T34051_e6178bb0-59ba-4df3-8dfa-3c50ca282d50.jpg?v=1783856413",
- "image_hi": "https://cdn.shopify.com/s/files/1/0015/4117/7456/files/T34051_e6178bb0-59ba-4df3-8dfa-3c50ca282d50_1200x.jpg?v=1783856413",
- "price": "141.72",
- "url": "https://designerwallcoverings.com/products/linen-weave-black-dwtt-74053",
- "created_at": "2026-07-12T04:40:10-07:00",
- "published_at": "2026-07-12T04:40:11-07:00"
- },
- {
- "id": 7882595467315,
- "handle": "linen-weave-navy-dwtt-74052",
- "title": "Linen Weave, Navy Wallcoverings | Thibaut",
- "pattern": "Linen Weave",
- "color": "Navy",
- "vendor": "Thibaut",
- "product_type": "Wallcovering",
- "image": "https://cdn.shopify.com/s/files/1/0015/4117/7456/files/T34050_dcbe3a42-e382-4371-abce-dd54f0c53594.jpg?v=1783856409",
- "image_hi": "https://cdn.shopify.com/s/files/1/0015/4117/7456/files/T34050_dcbe3a42-e382-4371-abce-dd54f0c53594_1200x.jpg?v=1783856409",
- "price": "141.72",
- "url": "https://designerwallcoverings.com/products/linen-weave-navy-dwtt-74052",
- "created_at": "2026-07-12T04:40:06-07:00",
- "published_at": "2026-07-12T04:40:08-07:00"
- },
- {
- "id": 7882595303475,
- "handle": "linen-weave-mineral-dwtt-74051",
- "title": "Linen Weave, Mineral Wallcoverings | Thibaut",
- "pattern": "Linen Weave",
- "color": "Mineral",
- "vendor": "Thibaut",
- "product_type": "Wallcovering",
- "image": "https://cdn.shopify.com/s/files/1/0015/4117/7456/files/T34048_5758df5d-e9ce-4447-8604-7fd85aab83e4.jpg?v=1783856405",
- "image_hi": "https://cdn.shopify.com/s/files/1/0015/4117/7456/files/T34048_5758df5d-e9ce-4447-8604-7fd85aab83e4_1200x.jpg?v=1783856405",
- "price": "141.72",
- "url": "https://designerwallcoverings.com/products/linen-weave-mineral-dwtt-74051",
- "created_at": "2026-07-12T04:40:02-07:00",
- "published_at": "2026-07-12T04:40:04-07:00"
- },
- {
- "id": 7882477436979,
- "handle": "linen-weave-blue-dwtt-74050",
- "title": "Linen Weave, Blue Wallcoverings | Thibaut",
- "pattern": "Linen Weave",
- "color": "Blue",
- "vendor": "Thibaut",
- "product_type": "Wallcovering",
- "image": "https://cdn.shopify.com/s/files/1/0015/4117/7456/files/T34049_4b06c03a-9387-429d-9cef-472a006dfd4f.jpg?v=1783852818",
- "image_hi": "https://cdn.shopify.com/s/files/1/0015/4117/7456/files/T34049_4b06c03a-9387-429d-9cef-472a006dfd4f_1200x.jpg?v=1783852818",
- "price": "141.72",
- "url": "https://designerwallcoverings.com/products/linen-weave-blue-dwtt-74050",
- "created_at": "2026-07-12T03:40:16-07:00",
- "published_at": "2026-07-12T03:40:17-07:00"
- },
- {
- "id": 7882476585011,
- "handle": "linen-weave-robin-s-egg-dwtt-74049",
- "title": "Linen Weave, Robin's Egg Wallcoverings | Thibaut",
- "pattern": "Linen Weave",
- "color": "Robin's Egg",
- "vendor": "Thibaut",
- "product_type": "Wallcovering",
- "image": "https://cdn.shopify.com/s/files/1/0015/4117/7456/files/T34047_80482a6f-e1ee-49a9-8059-5fbc282a5471.jpg?v=1783852816",
- "image_hi": "https://cdn.shopify.com/s/files/1/0015/4117/7456/files/T34047_80482a6f-e1ee-49a9-8059-5fbc282a5471_1200x.jpg?v=1783852816",
- "price": "141.72",
- "url": "https://designerwallcoverings.com/products/linen-weave-robin-s-egg-dwtt-74049",
- "created_at": "2026-07-12T03:40:12-07:00",
- "published_at": "2026-07-12T03:40:13-07:00"
- },
- {
- "id": 7882476519475,
- "handle": "linen-weave-pine-green-dwtt-74048",
- "title": "Linen Weave, Pine Green Wallcoverings | Thibaut",
- "pattern": "Linen Weave",
- "color": "Pine Green",
- "vendor": "Thibaut",
- "product_type": "Wallcovering",
- "image": "https://cdn.shopify.com/s/files/1/0015/4117/7456/files/T34046_9db61692-640e-4db1-a993-2ed542712fa6.jpg?v=1783852810",
- "image_hi": "https://cdn.shopify.com/s/files/1/0015/4117/7456/files/T34046_9db61692-640e-4db1-a993-2ed542712fa6_1200x.jpg?v=1783852810",
- "price": "141.72",
- "url": "https://designerwallcoverings.com/products/linen-weave-pine-green-dwtt-74048",
- "created_at": "2026-07-12T03:40:07-07:00",
- "published_at": "2026-07-12T03:40:09-07:00"
- },
- {
- "id": 7882353999923,
- "handle": "bristlecone-green-and-black-dwtt-74047",
- "title": "Bristlecone, Green and Black Wallcoverings | Thibaut",
- "pattern": "Bristlecone",
- "color": "Green and Black",
- "vendor": "Thibaut",
- "product_type": "Wallcovering",
- "image": "https://cdn.shopify.com/s/files/1/0015/4117/7456/files/T34034.jpg?v=1783849218",
- "image_hi": "https://cdn.shopify.com/s/files/1/0015/4117/7456/files/T34034_1200x.jpg?v=1783849218",
- "price": "125.43",
- "url": "https://designerwallcoverings.com/products/bristlecone-green-and-black-dwtt-74047",
- "created_at": "2026-07-12T02:40:15-07:00",
- "published_at": "2026-07-12T02:40:17-07:00"
- },
- {
- "id": 7882353967155,
- "handle": "bristlecone-navy-dwtt-74046",
- "title": "Bristlecone, Navy Wallcoverings | Thibaut",
- "pattern": "Bristlecone",
- "color": "Navy",
- "vendor": "Thibaut",
- "product_type": "Wallcovering",
- "image": "https://cdn.shopify.com/s/files/1/0015/4117/7456/files/T34033_d2e7996b-e53c-470d-a98d-55408c090b02.jpg?v=1783849215",
- "image_hi": "https://cdn.shopify.com/s/files/1/0015/4117/7456/files/T34033_d2e7996b-e53c-470d-a98d-55408c090b02_1200x.jpg?v=1783849215",
- "price": "125.43",
- "url": "https://designerwallcoverings.com/products/bristlecone-navy-dwtt-74046",
- "created_at": "2026-07-12T02:40:12-07:00",
- "published_at": "2026-07-12T02:40:13-07:00"
- },
- {
- "id": 7882353836083,
- "handle": "bristlecone-grey-dwtt-74045",
- "title": "Bristlecone, Grey Wallcoverings | Thibaut",
- "pattern": "Bristlecone",
- "color": "Grey",
- "vendor": "Thibaut",
- "product_type": "Wallcovering",
- "image": "https://cdn.shopify.com/s/files/1/0015/4117/7456/files/T34032_832bf857-636c-4f0b-abc4-48c380b70592.jpg?v=1783849211",
- "image_hi": "https://cdn.shopify.com/s/files/1/0015/4117/7456/files/T34032_832bf857-636c-4f0b-abc4-48c380b70592_1200x.jpg?v=1783849211",
- "price": "125.43",
- "url": "https://designerwallcoverings.com/products/bristlecone-grey-dwtt-74045",
- "created_at": "2026-07-12T02:40:07-07:00",
- "published_at": "2026-07-12T02:40:09-07:00"
+ "id": 1496061050992,
+ "handle": "medici-real-cork-damask-wallpaper-cork-92713",
+ "title": "Medici Real Cork Damask | Phillipe Romano",
+ "pattern": "Medici Real Cork Damask",
+ "color": "",
+ "vendor": "Phillipe Romano",
+ "product_type": "Wallcovering",
+ "image": "https://cdn.shopify.com/s/files/1/0015/4117/7456/products/e6fe9a61a73a3553bf96ece3dac43bf7.jpg?v=1775084623",
+ "image_hi": "https://cdn.shopify.com/s/files/1/0015/4117/7456/products/e6fe9a61a73a3553bf96ece3dac43bf7_1200x.jpg?v=1775084623",
+ "price": "43.76",
+ "url": "https://designerwallcoverings.com/products/medici-real-cork-damask-wallpaper-cork-92713",
+ "created_at": "2018-09-29T22:03:14-07:00",
+ "published_at": "2026-01-30T16:49:11-08:00"
+ },
+ {
+ "id": 1496097259632,
+ "handle": "carolina-cork-wallcovering-cork-827",
+ "title": "Carolina Cork Navy | Phillipe Romano",
+ "pattern": "Carolina Cork Navy",
+ "color": "",
+ "vendor": "Phillipe Romano",
+ "product_type": "Others",
+ "image": "https://cdn.shopify.com/s/files/1/0015/4117/7456/products/7f719339f4f3b4e6737c3de71551d15c.jpg?v=1745460340",
+ "image_hi": "https://cdn.shopify.com/s/files/1/0015/4117/7456/products/7f719339f4f3b4e6737c3de71551d15c_1200x.jpg?v=1745460340",
+ "price": "357.88",
+ "url": "https://designerwallcoverings.com/products/carolina-cork-wallcovering-cork-827",
+ "created_at": "2018-09-29T22:24:09-07:00",
+ "published_at": "2026-01-30T16:48:33-08:00"
+ },
+ {
+ "id": 1496058986608,
+ "handle": "latigo-real-cork-wallpaper-cork-92701",
+ "title": "Latigo Real Cork | Phillipe Romano",
+ "pattern": "Latigo Real Cork",
+ "color": "",
+ "vendor": "Phillipe Romano",
+ "product_type": "Wallcovering",
+ "image": "https://cdn.shopify.com/s/files/1/0015/4117/7456/products/6c7adc6d045aa5d6e3ca6da21196017d.jpg?v=1745460418",
+ "image_hi": "https://cdn.shopify.com/s/files/1/0015/4117/7456/products/6c7adc6d045aa5d6e3ca6da21196017d_1200x.jpg?v=1745460418",
+ "price": "43.76",
+ "url": "https://designerwallcoverings.com/products/latigo-real-cork-wallpaper-cork-92701",
+ "created_at": "2018-09-29T22:02:01-07:00",
+ "published_at": "2026-01-30T16:49:27-08:00"
+ },
+ {
+ "id": 1496054694000,
+ "handle": "corkytown-real-cork-wallpaper-cork-98605",
+ "title": "Corkytown Real Cork | Phillipe Romano",
+ "pattern": "Corkytown Real Cork",
+ "color": "",
+ "vendor": "Phillipe Romano",
+ "product_type": "Wallcovering",
+ "image": "https://cdn.shopify.com/s/files/1/0015/4117/7456/products/05ff41edbe53075093de08e67597a75c.jpg?v=1775080877",
+ "image_hi": "https://cdn.shopify.com/s/files/1/0015/4117/7456/products/05ff41edbe53075093de08e67597a75c_1200x.jpg?v=1775080877",
+ "price": "44.71",
+ "url": "https://designerwallcoverings.com/products/corkytown-real-cork-wallpaper-cork-98605",
+ "created_at": "2018-09-29T21:59:28-07:00",
+ "published_at": "2026-01-30T16:49:48-08:00"
+ },
+ {
+ "id": 1502320328816,
+ "handle": "la-corka-prt-74057",
+ "title": "La Corka | Phillipe Romano",
+ "pattern": "La Corka",
+ "color": "",
+ "vendor": "Phillipe Romano",
+ "product_type": "Wallcovering",
+ "image": "https://cdn.shopify.com/s/files/1/0015/4117/7456/products/d924346a4b5de58cc0888aed79bf74c0.jpg?v=1745456145",
+ "image_hi": "https://cdn.shopify.com/s/files/1/0015/4117/7456/products/d924346a4b5de58cc0888aed79bf74c0_1200x.jpg?v=1745456145",
+ "price": "4.25",
+ "url": "https://designerwallcoverings.com/products/la-corka-prt-74057",
+ "created_at": "2018-10-01T20:10:44-07:00",
+ "published_at": "2026-01-30T13:48:06-08:00"
+ },
+ {
+ "id": 1496095490160,
+ "handle": "braga-cork-wallcovering-cork-805",
+ "title": "Braga Cork Natural | Phillipe Romano",
+ "pattern": "Braga Cork Natural",
+ "color": "",
+ "vendor": "Phillipe Romano",
+ "product_type": "Others",
+ "image": "https://cdn.shopify.com/s/files/1/0015/4117/7456/products/13ee78efd60561e2f14a3be03a4083f7.jpg?v=1745460359",
+ "image_hi": "https://cdn.shopify.com/s/files/1/0015/4117/7456/products/13ee78efd60561e2f14a3be03a4083f7_1200x.jpg?v=1745460359",
+ "price": "404.41",
+ "url": "https://designerwallcoverings.com/products/braga-cork-wallcovering-cork-805",
+ "created_at": "2018-09-29T22:23:13-07:00",
+ "published_at": "2026-01-30T16:48:42-08:00"
+ },
+ {
+ "id": 1496096899184,
+ "handle": "gregoria-cork-wallcovering-cork-825",
+ "title": "Gregoria Cork | Phillipe Romano",
+ "pattern": "Gregoria Cork",
+ "color": "",
+ "vendor": "Phillipe Romano",
+ "product_type": "Others",
+ "image": "https://cdn.shopify.com/s/files/1/0015/4117/7456/products/6b842f7689ec412eb0c7f28bf869b16d.jpg?v=1745460344",
+ "image_hi": "https://cdn.shopify.com/s/files/1/0015/4117/7456/products/6b842f7689ec412eb0c7f28bf869b16d_1200x.jpg?v=1745460344",
+ "price": "357.88",
+ "url": "https://designerwallcoverings.com/products/gregoria-cork-wallcovering-cork-825",
+ "created_at": "2018-09-29T22:23:57-07:00",
+ "published_at": "2026-01-30T16:48:36-08:00"
+ },
+ {
+ "id": 1496095752304,
+ "handle": "espanoza-cork-wallcovering-cork-806",
+ "title": "Espanoza Cork | Phillipe Romano",
+ "pattern": "Espanoza Cork",
+ "color": "",
+ "vendor": "Phillipe Romano",
+ "product_type": "Others",
+ "image": "https://cdn.shopify.com/s/files/1/0015/4117/7456/products/f6d91ceecfcf2507631de04f1068f277.jpg?v=1745460357",
+ "image_hi": "https://cdn.shopify.com/s/files/1/0015/4117/7456/products/f6d91ceecfcf2507631de04f1068f277_1200x.jpg?v=1745460357",
+ "price": "404.41",
+ "url": "https://designerwallcoverings.com/products/espanoza-cork-wallcovering-cork-806",
+ "created_at": "2018-09-29T22:23:20-07:00",
+ "published_at": "2026-01-30T16:48:42-08:00"
+ },
+ {
+ "id": 1498247725168,
+ "handle": "oxel-cork-wallpaper-inw-4899",
+ "title": "Oxel Cork | Phillipe Romano",
+ "pattern": "Oxel Cork",
+ "color": "",
+ "vendor": "Phillipe Romano",
+ "product_type": "Wallcovering",
+ "image": "https://cdn.shopify.com/s/files/1/0015/4117/7456/products/e936c0fe6056aa8c2c621fb38bcfde70.jpg?v=1745458888",
+ "image_hi": "https://cdn.shopify.com/s/files/1/0015/4117/7456/products/e936c0fe6056aa8c2c621fb38bcfde70_1200x.jpg?v=1745458888",
+ "price": "93.60",
+ "url": "https://designerwallcoverings.com/products/oxel-cork-wallpaper-inw-4899",
+ "created_at": "2018-09-30T15:12:59-07:00",
+ "published_at": "2026-01-30T15:36:42-08:00"
+ },
+ {
+ "id": 1496057512048,
+ "handle": "mica-madness-real-cork-chip-wallpapers-mic-98621",
+ "title": "Mica Madness Real Cork Chip s | Phillipe Romano",
+ "pattern": "Mica Madness Real Cork Chip s",
+ "color": "",
+ "vendor": "Phillipe Romano",
+ "product_type": "Wallcovering",
+ "image": "https://cdn.shopify.com/s/files/1/0015/4117/7456/products/1d13ceb2cc53fca0c0eed77d922f1bda.jpg?v=1775082717",
+ "image_hi": "https://cdn.shopify.com/s/files/1/0015/4117/7456/products/1d13ceb2cc53fca0c0eed77d922f1bda_1200x.jpg?v=1775082717",
+ "price": "34.12",
+ "url": "https://designerwallcoverings.com/products/mica-madness-real-cork-chip-wallpapers-mic-98621",
+ "created_at": "2018-09-29T22:01:07-07:00",
+ "published_at": "2026-04-23T16:56:30-07:00"
+ },
+ {
+ "id": 1498194673776,
+ "handle": "aichi-natural-cork-wallpaper-lck-105",
+ "title": "Aichi Natural Cork Silver Stria on Silver Metallic | Phillipe Romano",
+ "pattern": "Aichi Natural Cork Silver Stria on Silver Metallic",
+ "color": "",
+ "vendor": "Phillipe Romano",
+ "product_type": "Wallcovering",
+ "image": "https://cdn.shopify.com/s/files/1/0015/4117/7456/products/6e48421353fc249278bbbf98087dbb86.jpg?v=1745458958",
+ "image_hi": "https://cdn.shopify.com/s/files/1/0015/4117/7456/products/6e48421353fc249278bbbf98087dbb86_1200x.jpg?v=1745458958",
+ "price": "93.50",
+ "url": "https://designerwallcoverings.com/products/aichi-natural-cork-wallpaper-lck-105",
+ "created_at": "2018-09-30T14:56:18-07:00",
+ "published_at": "2026-01-30T15:37:27-08:00"
+ },
+ {
+ "id": 1496984486000,
+ "handle": "bella-ravena-wood-metallic-cork-print-prn-62335",
+ "title": "Bella Ravena Wood Metallic Cork Print | Phillipe Romano",
+ "pattern": "Bella Ravena Wood Metallic Cork Print",
+ "color": "",
+ "vendor": "Phillipe Romano",
+ "product_type": "Wallcovering",
+ "image": "https://cdn.shopify.com/s/files/1/0015/4117/7456/products/53508bf9b737da1572bfb2ffe5cd7c70.jpg?v=1775116500",
+ "image_hi": "https://cdn.shopify.com/s/files/1/0015/4117/7456/products/53508bf9b737da1572bfb2ffe5cd7c70_1200x.jpg?v=1775116500",
+ "price": "41.36",
+ "url": "https://designerwallcoverings.com/products/bella-ravena-wood-metallic-cork-print-prn-62335",
+ "created_at": "2018-09-30T05:50:22-07:00",
+ "published_at": "2026-01-30T16:21:39-08:00"
+ },
+ {
+ "id": 1496977604720,
+ "handle": "bella-palermo-metallic-stone-slab-print-on-cork-prn-62316",
+ "title": "Bella Palermo Metallic Stone Slab Print on Cork | Phillipe Romano",
+ "pattern": "Bella Palermo Metallic Stone Slab Print on Cork",
+ "color": "",
+ "vendor": "Phillipe Romano",
+ "product_type": "Wallcovering",
+ "image": "https://cdn.shopify.com/s/files/1/0015/4117/7456/products/27f4be973091fdf318c6318b624cbfba.jpg?v=1775114101",
+ "image_hi": "https://cdn.shopify.com/s/files/1/0015/4117/7456/products/27f4be973091fdf318c6318b624cbfba_1200x.jpg?v=1775114101",
+ "price": "41.36",
+ "url": "https://designerwallcoverings.com/products/bella-palermo-metallic-stone-slab-print-on-cork-prn-62316",
+ "created_at": "2018-09-30T05:46:12-07:00",
+ "published_at": "2026-01-30T16:21:57-08:00"
+ },
+ {
+ "id": 1498200735856,
+ "handle": "chiba-natural-cork-wallpaper-lck-403",
+ "title": "Chiba Natural Cork Brown on Copper Metallic | Phillipe Romano",
+ "pattern": "Chiba Natural Cork Brown on Copper Metallic",
+ "color": "",
+ "vendor": "Phillipe Romano",
+ "product_type": "Wallcovering",
+ "image": "https://cdn.shopify.com/s/files/1/0015/4117/7456/products/37689b7be28bb9c49162e70bfe844f58.jpg?v=1745458918",
+ "image_hi": "https://cdn.shopify.com/s/files/1/0015/4117/7456/products/37689b7be28bb9c49162e70bfe844f58_1200x.jpg?v=1745458918",
+ "price": "93.50",
+ "url": "https://designerwallcoverings.com/products/chiba-natural-cork-wallpaper-lck-403",
+ "created_at": "2018-09-30T14:58:06-07:00",
+ "published_at": "2026-01-30T15:37:12-08:00"
+ },
+ {
+ "id": 1498201358448,
+ "handle": "okayama-natural-cork-wallpaper-lck-405",
+ "title": "Okayama Natural Cork Brown and Gold Metallic | Phillipe Romano",
+ "pattern": "Okayama Natural Cork Brown and Gold Metallic",
+ "color": "",
+ "vendor": "Phillipe Romano",
+ "product_type": "Wallcovering",
+ "image": "https://cdn.shopify.com/s/files/1/0015/4117/7456/products/7d69a86ea46389727c4f443323a37971.jpg?v=1745458914",
+ "image_hi": "https://cdn.shopify.com/s/files/1/0015/4117/7456/products/7d69a86ea46389727c4f443323a37971_1200x.jpg?v=1745458914",
+ "price": "93.50",
+ "url": "https://designerwallcoverings.com/products/okayama-natural-cork-wallpaper-lck-405",
+ "created_at": "2018-09-30T14:58:18-07:00",
+ "published_at": "2026-01-30T15:37:10-08:00"
+ },
+ {
+ "id": 1496097620080,
+ "handle": "malia-faux-cork-vinyl-cork-829",
+ "title": "Malia Faux Cork Vinyl | Phillipe Romano",
+ "pattern": "Malia Faux Cork Vinyl",
+ "color": "",
+ "vendor": "Phillipe Romano",
+ "product_type": "Wallcovering",
+ "image": "https://cdn.shopify.com/s/files/1/0015/4117/7456/products/c13e5329b5125a4f35b877b1b3e769e3.jpg?v=1745460335",
+ "image_hi": "https://cdn.shopify.com/s/files/1/0015/4117/7456/products/c13e5329b5125a4f35b877b1b3e769e3_1200x.jpg?v=1745460335",
+ "price": "169.59",
+ "url": "https://designerwallcoverings.com/products/malia-faux-cork-vinyl-cork-829",
+ "created_at": "2018-09-29T22:24:22-07:00",
+ "published_at": "2026-01-30T16:48:28-08:00"
+ },
+ {
+ "id": 1498196312176,
+ "handle": "fukuoka-natural-cork-wallpaper-lck-203",
+ "title": "Fukuoka Natural Cork | Phillipe Romano",
+ "pattern": "Fukuoka Natural Cork",
+ "color": "",
+ "vendor": "Phillipe Romano",
+ "product_type": "Wallcovering",
+ "image": "https://cdn.shopify.com/s/files/1/0015/4117/7456/products/eac5f0f8d8783b0b71eb7d6d06c3d330.jpg?v=1745458947",
+ "image_hi": "https://cdn.shopify.com/s/files/1/0015/4117/7456/products/eac5f0f8d8783b0b71eb7d6d06c3d330_1200x.jpg?v=1745458947",
+ "price": "93.50",
+ "url": "https://designerwallcoverings.com/products/fukuoka-natural-cork-wallpaper-lck-203",
+ "created_at": "2018-09-30T14:56:46-07:00",
+ "published_at": "2026-01-30T15:37:23-08:00"
+ },
+ {
+ "id": 1496991072368,
+ "handle": "bellla-bologna-metallic-cork-prn-62372",
+ "title": "Bellla Bologna Metallic Cork | Phillipe Romano",
+ "pattern": "Bellla Bologna Metallic Cork",
+ "color": "",
+ "vendor": "Phillipe Romano",
+ "product_type": "Wallcovering",
+ "image": "https://cdn.shopify.com/s/files/1/0015/4117/7456/products/cf9e213f3c0cfd30ec9fe5391cf9a2ff.jpg?v=1775118809",
+ "image_hi": "https://cdn.shopify.com/s/files/1/0015/4117/7456/products/cf9e213f3c0cfd30ec9fe5391cf9a2ff_1200x.jpg?v=1775118809",
+ "price": "34.41",
+ "url": "https://designerwallcoverings.com/products/bellla-bologna-metallic-cork-prn-62372",
+ "created_at": "2018-09-30T05:53:55-07:00",
+ "published_at": "2026-01-30T16:21:06-08:00"
+ },
+ {
+ "id": 1496096571504,
+ "handle": "medelin-cork-wallcovering-cork-817",
+ "title": "Medelin Cork | Phillipe Romano",
+ "pattern": "Medelin Cork",
+ "color": "",
+ "vendor": "Phillipe Romano",
+ "product_type": "Others",
+ "image": "https://cdn.shopify.com/s/files/1/0015/4117/7456/products/e54125d7e3ea502b2eaa9c566c05adf0.jpg?v=1745460348",
+ "image_hi": "https://cdn.shopify.com/s/files/1/0015/4117/7456/products/e54125d7e3ea502b2eaa9c566c05adf0_1200x.jpg?v=1745460348",
+ "price": "357.88",
+ "url": "https://designerwallcoverings.com/products/medelin-cork-wallcovering-cork-817",
+ "created_at": "2018-09-29T22:23:45-07:00",
+ "published_at": "2026-01-30T16:48:38-08:00"
+ },
+ {
+ "id": 1496983863408,
+ "handle": "bella-parma-modern-metal-cork-print-prn-62332",
+ "title": "Bella Parma Modern Metal Cork Print | Phillipe Romano",
+ "pattern": "Bella Parma Modern Metal Cork Print",
+ "color": "",
+ "vendor": "Phillipe Romano",
+ "product_type": "Wallcovering",
+ "image": "https://cdn.shopify.com/s/files/1/0015/4117/7456/products/c10fcf9ed4fc5cecb55cacdaaa4dfff6.jpg?v=1775116147",
+ "image_hi": "https://cdn.shopify.com/s/files/1/0015/4117/7456/products/c10fcf9ed4fc5cecb55cacdaaa4dfff6_1200x.jpg?v=1775116147",
+ "price": "41.36",
+ "url": "https://designerwallcoverings.com/products/bella-parma-modern-metal-cork-print-prn-62332",
+ "created_at": "2018-09-30T05:50:02-07:00",
+ "published_at": "2026-01-30T16:21:43-08:00"
+ },
+ {
+ "id": 1496096112752,
+ "handle": "suarez-cork-wallcovering-cork-809",
+ "title": "Suarez Cork | Phillipe Romano",
+ "pattern": "Suarez Cork",
+ "color": "",
+ "vendor": "Phillipe Romano",
+ "product_type": "Others",
+ "image": "https://cdn.shopify.com/s/files/1/0015/4117/7456/products/e6b8c207509f1e0a1b721ea78a334397.jpg?v=1745460353",
+ "image_hi": "https://cdn.shopify.com/s/files/1/0015/4117/7456/products/e6b8c207509f1e0a1b721ea78a334397_1200x.jpg?v=1745460353",
+ "price": "404.41",
+ "url": "https://designerwallcoverings.com/products/suarez-cork-wallcovering-cork-809",
+ "created_at": "2018-09-29T22:23:32-07:00",
+ "published_at": "2026-01-30T16:48:40-08:00"
+ },
+ {
+ "id": 1500597977200,
+ "handle": "faguli-real-cork-cork-34176",
+ "title": "Faguli Real Cork | Phillipe Romano",
+ "pattern": "Faguli Real Cork",
+ "color": "",
+ "vendor": "Phillipe Romano",
+ "product_type": "Wallcovering",
+ "image": "https://cdn.shopify.com/s/files/1/0015/4117/7456/files/faguli-real-cork-cork-34176.jpg?v=1782862333",
+ "image_hi": "https://cdn.shopify.com/s/files/1/0015/4117/7456/files/faguli-real-cork-cork-34176_1200x.jpg?v=1782862333",
+ "price": "4.25",
+ "url": "https://designerwallcoverings.com/products/faguli-real-cork-cork-34176",
+ "created_at": "2018-10-01T08:24:29-07:00",
+ "published_at": "2026-01-30T14:23:37-08:00"
+ },
+ {
+ "id": 1498195886192,
+ "handle": "kyoto-natural-cork-wallpaper-lck-202",
+ "title": "Kyoto Natural Cork Natural Cork on Gold | Phillipe Romano",
+ "pattern": "Kyoto Natural Cork Natural Cork on Gold",
+ "color": "",
+ "vendor": "Phillipe Romano",
+ "product_type": "Wallcovering",
+ "image": "https://cdn.shopify.com/s/files/1/0015/4117/7456/products/ed5ed36317e81635dc6f7fabc0019dcd.jpg?v=1745458949",
+ "image_hi": "https://cdn.shopify.com/s/files/1/0015/4117/7456/products/ed5ed36317e81635dc6f7fabc0019dcd_1200x.jpg?v=1745458949",
+ "price": "93.50",
+ "url": "https://designerwallcoverings.com/products/kyoto-natural-cork-wallpaper-lck-202",
+ "created_at": "2018-09-30T14:56:39-07:00",
+ "published_at": "2026-01-30T15:37:23-08:00"
+ },
+ {
+ "id": 1496095981680,
+ "handle": "reynoso-cork-wallcovering-cork-807",
+ "title": "Reynoso Cork | Phillipe Romano",
+ "pattern": "Reynoso Cork",
+ "color": "",
+ "vendor": "Phillipe Romano",
+ "product_type": "Others",
+ "image": "https://cdn.shopify.com/s/files/1/0015/4117/7456/products/2db27d82dc86a365cdb7af09d1f043c2.jpg?v=1745460355",
+ "image_hi": "https://cdn.shopify.com/s/files/1/0015/4117/7456/products/2db27d82dc86a365cdb7af09d1f043c2_1200x.jpg?v=1745460355",
+ "price": "404.41",
+ "url": "https://designerwallcoverings.com/products/reynoso-cork-wallcovering-cork-807",
+ "created_at": "2018-09-29T22:23:26-07:00",
+ "published_at": "2026-01-30T16:48:42-08:00"
+ },
+ {
+ "id": 1498200408176,
+ "handle": "saitama-natural-cork-wallpaper-lck-402",
+ "title": "Saitama Natural Cork Natural and Bronze Metallic | Phillipe Romano",
+ "pattern": "Saitama Natural Cork Natural and Bronze Metallic",
+ "color": "",
+ "vendor": "Phillipe Romano",
+ "product_type": "Wallcovering",
+ "image": "https://cdn.shopify.com/s/files/1/0015/4117/7456/products/c3e2e1359efbb3fa174a1986815f2868.jpg?v=1745458920",
+ "image_hi": "https://cdn.shopify.com/s/files/1/0015/4117/7456/products/c3e2e1359efbb3fa174a1986815f2868_1200x.jpg?v=1745458920",
+ "price": "93.50",
+ "url": "https://designerwallcoverings.com/products/saitama-natural-cork-wallpaper-lck-402",
+ "created_at": "2018-09-30T14:57:59-07:00",
+ "published_at": "2026-01-30T15:37:12-08:00"
+ },
+ {
+ "id": 1498199392368,
+ "handle": "ehime-natural-cork-wallpaper-lck-305",
+ "title": "Ehime Natural Cork Chips on Black | Phillipe Romano",
+ "pattern": "Ehime Natural Cork Chips on Black",
+ "color": "",
+ "vendor": "Phillipe Romano",
+ "product_type": "Wallcovering",
+ "image": "https://cdn.shopify.com/s/files/1/0015/4117/7456/products/8834b0dd3374e7366e2a1bc495735a32.jpg?v=1745458926",
+ "image_hi": "https://cdn.shopify.com/s/files/1/0015/4117/7456/products/8834b0dd3374e7366e2a1bc495735a32_1200x.jpg?v=1745458926",
+ "price": "93.50",
+ "url": "https://designerwallcoverings.com/products/ehime-natural-cork-wallpaper-lck-305",
+ "created_at": "2018-09-30T14:57:39-07:00",
+ "published_at": "2026-01-30T15:37:16-08:00"
+ },
+ {
+ "id": 1498198999152,
+ "handle": "hyigi-natural-cork-wallpaper-lck-304",
+ "title": "Hyigi Natural Cork Dark Brown Stria | Phillipe Romano",
+ "pattern": "Hyigi Natural Cork Dark Brown Stria",
+ "color": "",
+ "vendor": "Phillipe Romano",
+ "product_type": "Wallcovering",
+ "image": "https://cdn.shopify.com/s/files/1/0015/4117/7456/products/d6a35cd69b5f7e3c2a124b5953aa1c79.jpg?v=1745458928",
+ "image_hi": "https://cdn.shopify.com/s/files/1/0015/4117/7456/products/d6a35cd69b5f7e3c2a124b5953aa1c79_1200x.jpg?v=1745458928",
+ "price": "93.50",
+ "url": "https://designerwallcoverings.com/products/hyigi-natural-cork-wallpaper-lck-304",
+ "created_at": "2018-09-30T14:57:32-07:00",
+ "published_at": "2026-01-30T15:37:16-08:00"
+ },
+ {
+ "id": 1496983240816,
+ "handle": "bella-prato-metallic-modern-dots-on-cork-prn-62329",
+ "title": "Bella Prato Metallic Modern Dots on Cork | Phillipe Romano",
+ "pattern": "Bella Prato Metallic Modern Dots on Cork",
+ "color": "",
+ "vendor": "Phillipe Romano",
+ "product_type": "Wallcovering",
+ "image": "https://cdn.shopify.com/s/files/1/0015/4117/7456/products/aa4f2ca4953d132875faecd9812e678c.jpg?v=1775115805",
+ "image_hi": "https://cdn.shopify.com/s/files/1/0015/4117/7456/products/aa4f2ca4953d132875faecd9812e678c_1200x.jpg?v=1775115805",
+ "price": "41.36",
+ "url": "https://designerwallcoverings.com/products/bella-prato-metallic-modern-dots-on-cork-prn-62329",
+ "created_at": "2018-09-30T05:49:44-07:00",
+ "published_at": "2026-01-30T16:21:45-08:00"
+ },
+ {
+ "id": 1498200080496,
+ "handle": "osaka-natural-cork-wallpaper-lck-401",
+ "title": "Osaka Natural Cork Gold Metallic | Phillipe Romano",
+ "pattern": "Osaka Natural Cork Gold Metallic",
+ "color": "",
+ "vendor": "Phillipe Romano",
+ "product_type": "Wallcovering",
+ "image": "https://cdn.shopify.com/s/files/1/0015/4117/7456/products/f94cc6a86948e4d8ad31dd23cd2723bb.jpg?v=1745458922",
+ "image_hi": "https://cdn.shopify.com/s/files/1/0015/4117/7456/products/f94cc6a86948e4d8ad31dd23cd2723bb_1200x.jpg?v=1745458922",
+ "price": "93.50",
+ "url": "https://designerwallcoverings.com/products/osaka-natural-cork-wallpaper-lck-401",
+ "created_at": "2018-09-30T14:57:53-07:00",
+ "published_at": "2026-01-30T15:37:14-08:00"
+ },
+ {
+ "id": 1498198605936,
+ "handle": "tokyo-natural-cork-wallpaper-lck-303",
+ "title": "Tokyo Natural Cork Natural on Dark Brown | Phillipe Romano",
+ "pattern": "Tokyo Natural Cork Natural on Dark Brown",
+ "color": "",
+ "vendor": "Phillipe Romano",
+ "product_type": "Wallcovering",
+ "image": "https://cdn.shopify.com/s/files/1/0015/4117/7456/products/5d1354bf8d68b6f2faf8ad89c86ef420.jpg?v=1745458930",
+ "image_hi": "https://cdn.shopify.com/s/files/1/0015/4117/7456/products/5d1354bf8d68b6f2faf8ad89c86ef420_1200x.jpg?v=1745458930",
+ "price": "93.50",
+ "url": "https://designerwallcoverings.com/products/tokyo-natural-cork-wallpaper-lck-303",
+ "created_at": "2018-09-30T14:57:26-07:00",
+ "published_at": "2026-01-30T15:37:17-08:00"
+ },
+ {
+ "id": 1498196705392,
+ "handle": "kanda-natural-cork-wallpaper-lck-204",
+ "title": "Kanda Natural Cork | Phillipe Romano",
+ "pattern": "Kanda Natural Cork",
+ "color": "",
+ "vendor": "Phillipe Romano",
+ "product_type": "Wallcovering",
+ "image": "https://cdn.shopify.com/s/files/1/0015/4117/7456/products/dd12dcf5b2921f934a52f576fa935109.jpg?v=1745458941",
+ "image_hi": "https://cdn.shopify.com/s/files/1/0015/4117/7456/products/dd12dcf5b2921f934a52f576fa935109_1200x.jpg?v=1745458941",
+ "price": "93.50",
+ "url": "https://designerwallcoverings.com/products/kanda-natural-cork-wallpaper-lck-204",
+ "created_at": "2018-09-30T14:56:53-07:00",
+ "published_at": "2026-01-30T15:37:21-08:00"
+ },
+ {
+ "id": 1498194280560,
+ "handle": "osaka-natural-cork-wallpaper-lck-103",
+ "title": "Osaka Natural Cork Copper Painted on Copper Metallic | Phillipe Romano",
+ "pattern": "Osaka Natural Cork Copper Painted on Copper Metallic",
+ "color": "",
+ "vendor": "Phillipe Romano",
+ "product_type": "Wallcovering",
+ "image": "https://cdn.shopify.com/s/files/1/0015/4117/7456/products/8dc83aa9ee23fa544ad0dd6b93ee13c6.jpg?v=1745458961",
+ "image_hi": "https://cdn.shopify.com/s/files/1/0015/4117/7456/products/8dc83aa9ee23fa544ad0dd6b93ee13c6_1200x.jpg?v=1745458961",
+ "price": "93.50",
+ "url": "https://designerwallcoverings.com/products/osaka-natural-cork-wallpaper-lck-103",
+ "created_at": "2018-09-30T14:56:11-07:00",
+ "published_at": "2026-01-30T15:37:27-08:00"
+ },
+ {
+ "id": 1498193854576,
+ "handle": "kanagawa-natural-cork-wallpaper-lck-102",
+ "title": "Kanagawa Natural Cork Gold Paint on Gold Metallic | Phillipe Romano",
+ "pattern": "Kanagawa Natural Cork Gold Paint on Gold Metallic",
+ "color": "",
+ "vendor": "Phillipe Romano",
+ "product_type": "Wallcovering",
+ "image": "https://cdn.shopify.com/s/files/1/0015/4117/7456/products/843b25f182cc2b9b9bd8ce4057f4fc00.jpg?v=1745458964",
+ "image_hi": "https://cdn.shopify.com/s/files/1/0015/4117/7456/products/843b25f182cc2b9b9bd8ce4057f4fc00_1200x.jpg?v=1745458964",
+ "price": "93.50",
+ "url": "https://designerwallcoverings.com/products/kanagawa-natural-cork-wallpaper-lck-102",
+ "created_at": "2018-09-30T14:56:03-07:00",
+ "published_at": "2026-01-30T15:37:29-08:00"
+ },
+ {
+ "id": 1496097816688,
+ "handle": "ala-marsala-faux-cork-vinyl-cork-830",
+ "title": "Ala Marsala Faux Cork Vinyl | Phillipe Romano",
+ "pattern": "Ala Marsala Faux Cork Vinyl",
+ "color": "",
+ "vendor": "Phillipe Romano",
+ "product_type": "Wallcovering",
+ "image": "https://cdn.shopify.com/s/files/1/0015/4117/7456/products/2512dc87af845a9107dd4588ef2ddbd4.jpg?v=1745460333",
+ "image_hi": "https://cdn.shopify.com/s/files/1/0015/4117/7456/products/2512dc87af845a9107dd4588ef2ddbd4_1200x.jpg?v=1745460333",
+ "price": "169.59",
+ "url": "https://designerwallcoverings.com/products/ala-marsala-faux-cork-vinyl-cork-830",
+ "created_at": "2018-09-29T22:24:27-07:00",
+ "published_at": "2026-01-30T16:48:28-08:00"
+ },
+ {
+ "id": 6672900325427,
+ "handle": "mr-miyago-cork-wallpaper-6",
+ "title": "Mr. Miyago Cork | Phillipe Romano",
+ "pattern": "Mr. Miyago Cork",
+ "color": "",
+ "vendor": "Phillipe Romano",
+ "product_type": "Wallcovering",
+ "image": "https://cdn.shopify.com/s/files/1/0015/4117/7456/products/ScreenShot2022-05-05at12.25.09PM.png?v=1745455726",
+ "image_hi": "https://cdn.shopify.com/s/files/1/0015/4117/7456/products/ScreenShot2022-05-05at12.25.09PM_1200x.png?v=1745455726",
+ "price": "99.50",
+ "url": "https://designerwallcoverings.com/products/mr-miyago-cork-wallpaper-6",
+ "created_at": "2022-02-16T10:00:25-08:00",
+ "published_at": "2026-01-30T09:54:30-08:00"
+ },
+ {
+ "id": 1498201063536,
+ "handle": "pongo-natural-cork-wallpaper-lck-404",
+ "title": "Pongo Natural Cork Brown and Silver Metallic | Phillipe Romano",
+ "pattern": "Pongo Natural Cork Brown and Silver Metallic",
+ "color": "",
+ "vendor": "Phillipe Romano",
+ "product_type": "Wallcovering",
+ "image": "https://cdn.shopify.com/s/files/1/0015/4117/7456/products/484b2a510392c868822c79d5be224a0a.jpg?v=1745458916",
+ "image_hi": "https://cdn.shopify.com/s/files/1/0015/4117/7456/products/484b2a510392c868822c79d5be224a0a_1200x.jpg?v=1745458916",
+ "price": "93.50",
+ "url": "https://designerwallcoverings.com/products/pongo-natural-cork-wallpaper-lck-404",
+ "created_at": "2018-09-30T14:58:12-07:00",
+ "published_at": "2026-01-30T15:37:10-08:00"
+ },
+ {
+ "id": 1498195460208,
+ "handle": "hy-go-natural-cork-wallpaper-lck-201",
+ "title": "Hyago Natural Cork Silver Metallic | Phillipe Romano",
+ "pattern": "Hyago Natural Cork Silver Metallic",
+ "color": "",
+ "vendor": "Phillipe Romano",
+ "product_type": "Wallcovering",
+ "image": "https://cdn.shopify.com/s/files/1/0015/4117/7456/products/d0c343e1cf3f302e51429d0be48496f0.jpg?v=1745458951",
+ "image_hi": "https://cdn.shopify.com/s/files/1/0015/4117/7456/products/d0c343e1cf3f302e51429d0be48496f0_1200x.jpg?v=1745458951",
+ "price": "93.50",
+ "url": "https://designerwallcoverings.com/products/hy-go-natural-cork-wallpaper-lck-201",
+ "created_at": "2018-09-30T14:56:32-07:00",
+ "published_at": "2026-01-30T15:37:25-08:00"
+ },
+ {
+ "id": 1496097063024,
+ "handle": "lafayette-cork-wallcovering-cork-826",
+ "title": "Lafayette Cork | Phillipe Romano",
+ "pattern": "Lafayette Cork",
+ "color": "",
+ "vendor": "Phillipe Romano",
+ "product_type": "Others",
+ "image": "https://cdn.shopify.com/s/files/1/0015/4117/7456/products/e047936e1589e22b7596cadf78b9471c.jpg?v=1745460342",
+ "image_hi": "https://cdn.shopify.com/s/files/1/0015/4117/7456/products/e047936e1589e22b7596cadf78b9471c_1200x.jpg?v=1745460342",
+ "price": "357.88",
+ "url": "https://designerwallcoverings.com/products/lafayette-cork-wallcovering-cork-826",
+ "created_at": "2018-09-29T22:24:03-07:00",
+ "published_at": "2026-01-30T16:48:35-08:00"
+ },
+ {
+ "id": 1496992120944,
+ "handle": "bella-genoa-cork-print-prn-62377",
+ "title": "Bella Genoa Cork Print | Phillipe Romano",
+ "pattern": "Bella Genoa Cork Print",
+ "color": "",
+ "vendor": "Phillipe Romano",
+ "product_type": "Wallcovering",
+ "image": "https://cdn.shopify.com/s/files/1/0015/4117/7456/products/915fe8aee4c84c61d2f9bce8960c8555.jpg?v=1775119360",
+ "image_hi": "https://cdn.shopify.com/s/files/1/0015/4117/7456/products/915fe8aee4c84c61d2f9bce8960c8555_1200x.jpg?v=1775119360",
+ "price": "34.41",
+ "url": "https://designerwallcoverings.com/products/bella-genoa-cork-print-prn-62377",
+ "created_at": "2018-09-30T05:54:27-07:00",
+ "published_at": "2026-01-30T16:21:01-08:00"
+ },
+ {
+ "id": 1498197098608,
+ "handle": "saitama-natural-cork-wallpaper-lck-205",
+ "title": "Saitama Natural Cork Dark Brown | Phillipe Romano",
+ "pattern": "Saitama Natural Cork Dark Brown",
+ "color": "",
+ "vendor": "Phillipe Romano",
+ "product_type": "Wallcovering",
+ "image": "https://cdn.shopify.com/s/files/1/0015/4117/7456/products/556dc991bac89b4c260efadc434b1d8f.jpg?v=1745458939",
+ "image_hi": "https://cdn.shopify.com/s/files/1/0015/4117/7456/products/556dc991bac89b4c260efadc434b1d8f_1200x.jpg?v=1745458939",
+ "price": "93.50",
+ "url": "https://designerwallcoverings.com/products/saitama-natural-cork-wallpaper-lck-205",
+ "created_at": "2018-09-30T14:56:59-07:00",
+ "published_at": "2026-01-30T15:37:21-08:00"
+ },
+ {
+ "id": 1498197852272,
+ "handle": "miyagi-natural-cork-wallpaper-lck-301",
+ "title": "Miyagi Natural Cork Stripe | Phillipe Romano",
+ "pattern": "Miyagi Natural Cork Stripe",
+ "color": "",
+ "vendor": "Phillipe Romano",
+ "product_type": "Wallcovering",
+ "image": "https://cdn.shopify.com/s/files/1/0015/4117/7456/products/55390d9558f9ccb6a5f15b3a26bc32a1.jpg?v=1745458935",
+ "image_hi": "https://cdn.shopify.com/s/files/1/0015/4117/7456/products/55390d9558f9ccb6a5f15b3a26bc32a1_1200x.jpg?v=1745458935",
+ "price": "93.50",
+ "url": "https://designerwallcoverings.com/products/miyagi-natural-cork-wallpaper-lck-301",
+ "created_at": "2018-09-30T14:57:12-07:00",
+ "published_at": "2026-01-30T15:37:19-08:00"
+ },
+ {
+ "id": 1498197524592,
+ "handle": "hiroshima-natural-cork-wallpaper-lck-206",
+ "title": "Hiroshima Natural Cork Dark Brown | Phillipe Romano",
+ "pattern": "Hiroshima Natural Cork Dark Brown",
+ "color": "",
+ "vendor": "Phillipe Romano",
+ "product_type": "Wallcovering",
+ "image": "https://cdn.shopify.com/s/files/1/0015/4117/7456/products/0289c7e2a4d229970d46ceab89443a43.jpg?v=1745458937",
+ "image_hi": "https://cdn.shopify.com/s/files/1/0015/4117/7456/products/0289c7e2a4d229970d46ceab89443a43_1200x.jpg?v=1745458937",
+ "price": "93.50",
+ "url": "https://designerwallcoverings.com/products/hiroshima-natural-cork-wallpaper-lck-206",
+ "created_at": "2018-09-30T14:57:06-07:00",
+ "published_at": "2026-01-30T15:37:21-08:00"
+ },
+ {
+ "id": 1496097423472,
+ "handle": "corsica-faux-cork-vinyl-cork-828",
+ "title": "Corsica Faux Cork Vinyl | Phillipe Romano",
+ "pattern": "Corsica Faux Cork Vinyl",
+ "color": "",
+ "vendor": "Phillipe Romano",
+ "product_type": "Wallcovering",
+ "image": "https://cdn.shopify.com/s/files/1/0015/4117/7456/products/a91e2e6663095c656f4745465cec794b.jpg?v=1745460337",
+ "image_hi": "https://cdn.shopify.com/s/files/1/0015/4117/7456/products/a91e2e6663095c656f4745465cec794b_1200x.jpg?v=1745460337",
+ "price": "169.59",
+ "url": "https://designerwallcoverings.com/products/corsica-faux-cork-vinyl-cork-828",
+ "created_at": "2018-09-29T22:24:15-07:00",
+ "published_at": "2026-01-30T16:48:30-08:00"
+ },
+ {
+ "id": 1496096735344,
+ "handle": "florenza-cork-wallcovering-cork-823",
+ "title": "Florenza Cork | Phillipe Romano",
+ "pattern": "Florenza Cork",
+ "color": "",
+ "vendor": "Phillipe Romano",
+ "product_type": "Others",
+ "image": "https://cdn.shopify.com/s/files/1/0015/4117/7456/products/d296366a170cc943ef116a83a5071407.jpg?v=1745460346",
+ "image_hi": "https://cdn.shopify.com/s/files/1/0015/4117/7456/products/d296366a170cc943ef116a83a5071407_1200x.jpg?v=1745460346",
+ "price": "381.41",
+ "url": "https://designerwallcoverings.com/products/florenza-cork-wallcovering-cork-823",
+ "created_at": "2018-09-29T22:23:51-07:00",
+ "published_at": "2026-01-30T16:48:38-08:00"
+ },
+ {
+ "id": 1498754908272,
+ "handle": "trellis-cork-by-phillipe-romano-prc-84022",
+ "title": "Trellis Cork | Phillipe Romano",
+ "pattern": "Trellis Cork",
+ "color": "",
+ "vendor": "Phillipe Romano",
+ "product_type": "Wallcovering",
+ "image": "https://cdn.shopify.com/s/files/1/0015/4117/7456/products/6ae50bf7487effd1e06f56fd7a3ec22b.jpg?v=1745458795",
+ "image_hi": "https://cdn.shopify.com/s/files/1/0015/4117/7456/products/6ae50bf7487effd1e06f56fd7a3ec22b_1200x.jpg?v=1745458795",
+ "price": "58.95",
+ "url": "https://designerwallcoverings.com/products/trellis-cork-by-phillipe-romano-prc-84022",
+ "created_at": "2018-09-30T19:28:14-07:00",
+ "published_at": "2026-06-12T07:36:00-07:00"
+ },
+ {
+ "id": 1498753826928,
+ "handle": "gingko-cork-by-phillipe-romano-prc-84015",
+ "title": "Gingko Cork | Phillipe Romano",
+ "pattern": "Gingko Cork",
+ "color": "",
+ "vendor": "Phillipe Romano",
+ "product_type": "Wallcovering",
+ "image": "https://cdn.shopify.com/s/files/1/0015/4117/7456/products/6302279ac8433df2f10c4252d25b8816.jpg?v=1745458811",
+ "image_hi": "https://cdn.shopify.com/s/files/1/0015/4117/7456/products/6302279ac8433df2f10c4252d25b8816_1200x.jpg?v=1745458811",
+ "price": "58.95",
+ "url": "https://designerwallcoverings.com/products/gingko-cork-by-phillipe-romano-prc-84015",
+ "created_at": "2018-09-30T19:27:33-07:00",
+ "published_at": "2026-06-11T19:15:44-07:00"
+ },
+ {
+ "id": 1498201784432,
+ "handle": "kagoshima-natural-cork-wallpaper-lck-406",
+ "title": "Kagoshima Natural Cork Dark Brown on Black | Phillipe Romano",
+ "pattern": "Kagoshima Natural Cork Dark Brown on Black",
+ "color": "",
+ "vendor": "Phillipe Romano",
+ "product_type": "Wallcovering",
+ "image": "https://cdn.shopify.com/s/files/1/0015/4117/7456/products/485660fad626f92dcc05932951f6f6e3.jpg?v=1745458912",
+ "image_hi": "https://cdn.shopify.com/s/files/1/0015/4117/7456/products/485660fad626f92dcc05932951f6f6e3_1200x.jpg?v=1745458912",
+ "price": "93.50",
+ "url": "https://designerwallcoverings.com/products/kagoshima-natural-cork-wallpaper-lck-406",
+ "created_at": "2018-09-30T14:58:24-07:00",
+ "published_at": "2026-01-30T15:37:08-08:00"
+ },
+ {
+ "id": 1498199752816,
+ "handle": "tochigi-natural-cork-wallpaper-lck-306",
+ "title": "Tochigi Natural Cork Dark and Light Natural Cork | Phillipe Romano",
+ "pattern": "Tochigi Natural Cork Dark and Light Natural Cork",
+ "color": "",
+ "vendor": "Phillipe Romano",
+ "product_type": "Wallcovering",
+ "image": "https://cdn.shopify.com/s/files/1/0015/4117/7456/products/e2cf4f640c38ba61c0a9b85ed1a6d559.jpg?v=1745458924",
+ "image_hi": "https://cdn.shopify.com/s/files/1/0015/4117/7456/products/e2cf4f640c38ba61c0a9b85ed1a6d559_1200x.jpg?v=1745458924",
+ "price": "93.50",
+ "url": "https://designerwallcoverings.com/products/tochigi-natural-cork-wallpaper-lck-306",
+ "created_at": "2018-09-30T14:57:46-07:00",
+ "published_at": "2026-01-30T15:37:14-08:00"
+ },
+ {
+ "id": 1498195132528,
+ "handle": "hokkaido-natural-cork-wallpaper-lck-106",
+ "title": "Hokkaido Natural Cork Gold Paint on Gold Metallic | Phillipe Romano",
+ "pattern": "Hokkaido Natural Cork Gold Paint on Gold Metallic",
+ "color": "",
+ "vendor": "Phillipe Romano",
+ "product_type": "Wallcovering",
+ "image": "https://cdn.shopify.com/s/files/1/0015/4117/7456/products/93c817f242e843de418fe36298f7a521.jpg?v=1745458954",
+ "image_hi": "https://cdn.shopify.com/s/files/1/0015/4117/7456/products/93c817f242e843de418fe36298f7a521_1200x.jpg?v=1745458954",
+ "price": "93.50",
+ "url": "https://designerwallcoverings.com/products/hokkaido-natural-cork-wallpaper-lck-106",
+ "created_at": "2018-09-30T14:56:25-07:00",
+ "published_at": "2026-01-30T15:37:25-08:00"
+ },
+ {
+ "id": 1497563824240,
+ "handle": "caluvoto-gilded-cork-cork-72017",
+ "title": "Caluvoto Gilded Cork | Phillipe Romano",
+ "pattern": "Caluvoto Gilded Cork",
+ "color": "",
+ "vendor": "Phillipe Romano",
+ "product_type": "Wallcovering",
+ "image": "https://cdn.shopify.com/s/files/1/0015/4117/7456/products/381e473ab821d2b08a2091b1c57cef04.jpg?v=1745459429",
+ "image_hi": "https://cdn.shopify.com/s/files/1/0015/4117/7456/products/381e473ab821d2b08a2091b1c57cef04_1200x.jpg?v=1745459429",
+ "price": "4.25",
+ "url": "https://designerwallcoverings.com/products/caluvoto-gilded-cork-cork-72017",
+ "created_at": "2018-09-30T10:46:33-07:00",
+ "published_at": "2026-01-30T15:54:20-08:00"
+ },
+ {
+ "id": 1496098406512,
+ "handle": "manhattan-cork-vinyl-cork-840",
+ "title": "Manhattan Cork Vinyl | Phillipe Romano",
+ "pattern": "Manhattan Cork Vinyl",
+ "color": "",
+ "vendor": "Phillipe Romano",
+ "product_type": "Wallcovering",
+ "image": "https://cdn.shopify.com/s/files/1/0015/4117/7456/products/7e9660bae4b57eff616484170fb1d526.jpg?v=1745460329",
+ "image_hi": "https://cdn.shopify.com/s/files/1/0015/4117/7456/products/7e9660bae4b57eff616484170fb1d526_1200x.jpg?v=1745460329",
+ "price": "4.25",
+ "url": "https://designerwallcoverings.com/products/manhattan-cork-vinyl-cork-840",
+ "created_at": "2018-09-29T22:24:47-07:00",
+ "published_at": "2026-01-30T16:48:38-08:00"
+ },
+ {
+ "id": 1496098013296,
+ "handle": "medici-real-cork-stripe-wallpaper-cork",
+ "title": "Medici Real Cork Stripe | Phillipe Romano",
+ "pattern": "Medici Real Cork Stripe",
+ "color": "",
+ "vendor": "Phillipe Romano",
+ "product_type": "Wallcovering",
+ "image": "https://cdn.shopify.com/s/files/1/0015/4117/7456/products/07979e0a494f2201f1200d443a7c77ad_6bbbd130-5865-4f59-bde9-db602b08375e.jpg?v=1745460331",
+ "image_hi": "https://cdn.shopify.com/s/files/1/0015/4117/7456/products/07979e0a494f2201f1200d443a7c77ad_6bbbd130-5865-4f59-bde9-db602b08375e_1200x.jpg?v=1745460331",
+ "price": "169.59",
+ "url": "https://designerwallcoverings.com/products/medici-real-cork-stripe-wallpaper-cork",
+ "created_at": "2018-09-29T22:24:34-07:00",
+ "published_at": "2026-01-30T16:48:26-08:00"
+ },
+ {
+ "id": 6882877374515,
+ "handle": "dwjj-40860-daniele",
+ "title": "Daniele Cork Stripe Naturals | Phillipe Romano",
+ "pattern": "Daniele Cork Stripe Naturals",
+ "color": "",
+ "vendor": "Phillipe Romano",
+ "product_type": "Wallcovering",
+ "image": "https://cdn.shopify.com/s/files/1/0015/4117/7456/products/ScreenShot2023-01-13at12.48.16PM.png?v=1745455466",
+ "image_hi": "https://cdn.shopify.com/s/files/1/0015/4117/7456/products/ScreenShot2023-01-13at12.48.16PM_1200x.png?v=1745455466",
+ "price": "4.25",
+ "url": "https://designerwallcoverings.com/products/dwjj-40860-daniele",
+ "created_at": "2023-01-13T08:04:10-08:00",
+ "published_at": "2026-01-30T07:25:56-08:00"
}
]
}
\ No newline at end of file
diff --git a/data/reels.json b/data/reels.json
index 65a1e2b..de8a745 100644
--- a/data/reels.json
+++ b/data/reels.json
@@ -1,4 +1,43 @@
[
+ {
+ "file": "phillipe-romano-cork-2026-07-13-06-09.mp4",
+ "created_at": "2026-07-13T06:09:12.626Z",
+ "products": 8,
+ "seconds": 23.8,
+ "titles": [
+ "Medici Real Cork Damask / ",
+ "Carolina Cork Navy / ",
+ "Latigo Real Cork / ",
+ "Corkytown Real Cork / ",
+ "La Corka / ",
+ "Braga Cork Natural / ",
+ "Gregoria Cork / ",
+ "Espanoza Cork / "
+ ],
+ "caption": "Cork, reimagined ✨ Medici Real Cork Damask, Carolina Cork Navy, Latigo Real Cork & more from Phillipe Romano. Natural cork wallcoverings by Phillipe Romano — shop the collection at designerwallcoverings.com 🔗\n\n#DesignerWallcoverings #Cork #CorkWallcovering #PhillipeRomano #NaturalTexture #Wallpaper #Wallcovering #InteriorDesign #InteriorDecor #HomeDesign #LuxuryInteriors #DesignInspo",
+ "hashtags": [
+ "#DesignerWallcoverings",
+ "#Cork",
+ "#CorkWallcovering",
+ "#PhillipeRomano",
+ "#NaturalTexture",
+ "#Wallpaper",
+ "#Wallcovering",
+ "#InteriorDesign",
+ "#InteriorDecor",
+ "#HomeDesign",
+ "#LuxuryInteriors",
+ "#DesignInspo"
+ ],
+ "publish": {
+ "instagram": {
+ "status": "pending"
+ },
+ "tiktok": {
+ "status": "pending"
+ }
+ }
+ },
{
"file": "new-arrivals-2026-07-12-19-00.mp4",
"created_at": "2026-07-12T19:00:19.205Z",
diff --git a/scripts/build-reel.mjs b/scripts/build-reel.mjs
index 86175fc..5c8e637 100644
--- a/scripts/build-reel.mjs
+++ b/scripts/build-reel.mjs
@@ -13,6 +13,21 @@ const N = Number(process.env.REEL_COUNT || 6); // products per reel
const PER = Number(process.env.REEL_SECS || 2.4); // seconds per product
const INTRO = 2.0, OUTRO = 2.6;
+// Reel theming — all env-overridable, defaulting to the generic "New Arrivals" reel.
+// A themed run (e.g. Phillipe Romano corks) sets these to rebrand the cards + caption
+// without touching the render pipeline.
+const THEME = {
+ kicker: process.env.REEL_KICKER || 'New Arrivals',
+ title: process.env.REEL_TITLE || 'Just In',
+ subtitle: process.env.REEL_SUBTITLE || '', // '' → "Designer Wallcoverings · <Month Year>"
+ outroKicker: process.env.REEL_OUTRO_KICKER || 'Shop the collection',
+ outroBig: process.env.REEL_OUTRO_BIG || 'Designer<br/>Wallcoverings',
+ url: process.env.REEL_URL || 'designerwallcoverings.com',
+ captionLead: process.env.REEL_CAPTION_LEAD || 'New arrivals just landed ✨',
+ captionTail: process.env.REEL_CAPTION_TAIL || 'Discover the latest wallcoverings — shop the collection at designerwallcoverings.com 🔗',
+ tagsExtra: (process.env.REEL_HASHTAGS_EXTRA || '#NewArrivals').split(/\s+/).filter(Boolean),
+};
+
const esc = s => String(s || '').replace(/[&<>"]/g, c => ({ '&': '&', '<': '<', '>': '>', '"': '"' }[c]));
// Private-label / upstream names that must NEVER surface publicly (mirrors dw-leak-scanner).
@@ -25,12 +40,12 @@ function captionFor(items) {
const pats = [...new Set(items.map(i => i.pattern).filter(safe))];
const vendors = [...new Set(items.map(i => i.vendor).filter(safe))];
const lead = pats.slice(0, 3).join(', ');
- const body = `New arrivals just landed ✨ ${lead}${pats.length > 3 ? ' & more' : ''}`
+ const body = `${THEME.captionLead} ${lead}${pats.length > 3 ? ' & more' : ''}`
+ `${vendors.length ? ` from ${vendors.slice(0, 3).join(', ')}` : ''}.`
- + `\n\nDiscover the latest wallcoverings — shop the collection at designerwallcoverings.com 🔗`;
+ + `\n\n${THEME.captionTail}`;
const tagify = s => '#' + String(s).replace(/[^a-z0-9]+/gi, '');
const tags = [...new Set([
- '#DesignerWallcoverings', '#NewArrivals', '#Wallpaper', '#Wallcovering',
+ '#DesignerWallcoverings', ...THEME.tagsExtra, '#Wallpaper', '#Wallcovering',
'#InteriorDesign', '#InteriorDecor', '#HomeDesign', '#LuxuryInteriors', '#DesignInspo',
...vendors.slice(0, 3).map(tagify),
])].slice(0, 14);
@@ -66,6 +81,7 @@ async function main() {
const total = +(INTRO + items.length * PER + OUTRO).toFixed(2);
const dateStr = new Date().toLocaleDateString('en-US', { month: 'long', year: 'numeric' });
+ const introSub = THEME.subtitle || `Designer Wallcoverings · ${dateStr}`;
// --- slides markup ---
const slides = items.map((it, i) => `
@@ -125,18 +141,18 @@ async function main() {
data-width="1080" data-height="1920" data-start="0" data-duration="${total}">
<div class="card" id="intro">
- <div class="kicker">New Arrivals</div>
- <div class="big">Just In</div>
+ <div class="kicker">${esc(THEME.kicker)}</div>
+ <div class="big">${esc(THEME.title)}</div>
<div class="rule"></div>
- <div class="sub">Designer Wallcoverings · ${esc(dateStr)}</div>
+ <div class="sub">${esc(introSub)}</div>
</div>
${slides}
<div class="card" id="outro">
- <div class="kicker">Shop the collection</div>
- <div class="big">Designer<br/>Wallcoverings</div>
- <div class="url">designerwallcoverings.com</div>
+ <div class="kicker">${esc(THEME.outroKicker)}</div>
+ <div class="big">${THEME.outroBig}</div>
+ <div class="url">${esc(THEME.url)}</div>
</div>
<script>
@@ -179,9 +195,10 @@ ${anim}
console.log('→ rendering (local ffmpeg/Chrome, $0)…');
execSync('npx --yes hyperframes render', { cwd: WS, stdio: 'inherit', env: { ...process.env, HYPERFRAMES_SKIP_SKILLS: '1' } });
- // move newest mp4 to reels/
+ // move newest mp4 to reels/ (REEL_SLUG names themed reels; default keeps new-arrivals)
const stamp = new Date().toISOString().slice(0, 16).replace(/[:T]/g, '-');
- const outName = `new-arrivals-${stamp}.mp4`;
+ const slug = (process.env.REEL_SLUG || 'new-arrivals').replace(/[^a-z0-9-]+/gi, '-').toLowerCase();
+ const outName = `${slug}-${stamp}.mp4`;
const found = findMp4(WS);
if (found) {
mkdirSync(join(ROOT, 'reels'), { recursive: true });
diff --git a/scripts/fetch-new-arrivals.mjs b/scripts/fetch-new-arrivals.mjs
index d8c100e..1c84af1 100644
--- a/scripts/fetch-new-arrivals.mjs
+++ b/scripts/fetch-new-arrivals.mjs
@@ -12,6 +12,16 @@ const COLLECTION = process.env.DW_COLLECTION || 'new-arrivals';
const LIMIT = Number(process.env.DW_LIMIT || 24);
const UA = 'Mozilla/5.0 (dw-marketing-reels)';
+// Optional narrowing — all backwards-compatible (unset = generic collection dump).
+// DW_VENDOR: keep only products whose vendor matches (case-insensitive exact).
+// DW_TITLE_MATCH: keep only products whose title matches this regex (e.g. "cork").
+// DW_DEDUPE_PATTERN: "1" = one product per distinct pattern (drops repeated colorways).
+const VENDOR = (process.env.DW_VENDOR || '').trim();
+const TITLE_MATCH = process.env.DW_TITLE_MATCH ? new RegExp(process.env.DW_TITLE_MATCH, 'i') : null;
+const DEDUPE = process.env.DW_DEDUPE_PATTERN === '1';
+// Swatch/sample books are never a reel frame.
+const NON_PRODUCT = /collection book|swatch book|sample book|memo sample/i;
+
function cleanTitle(t = '') {
// "Katamari, Pewter Wallcoverings | Thibaut" -> {pattern:"Katamari", color:"Pewter", vendor:"Thibaut"}
const [main, vendor = ''] = t.split('|').map(s => s.trim());
@@ -30,7 +40,7 @@ async function main() {
if (!res.ok) throw new Error(`fetch ${url} -> ${res.status}`);
const { products = [] } = await res.json();
- const items = products
+ let items = products
.map(p => {
const img = (p.images || [])[0]?.src || '';
const variant = (p.variants || [])[0] || {};
@@ -52,7 +62,20 @@ async function main() {
published_at: p.published_at,
};
})
- .filter(x => x.image); // a reel frame needs an image
+ .filter(x => x.image) // a reel frame needs an image
+ .filter(x => !NON_PRODUCT.test(x.title)); // no swatch/sample books
+
+ if (VENDOR) items = items.filter(x => (x.vendor || '').toLowerCase() === VENDOR.toLowerCase());
+ if (TITLE_MATCH) items = items.filter(x => TITLE_MATCH.test(x.title));
+ if (DEDUPE) {
+ const seen = new Set();
+ items = items.filter(x => {
+ const k = x.pattern.toLowerCase();
+ if (seen.has(k)) return false;
+ seen.add(k);
+ return true;
+ });
+ }
mkdirSync(join(ROOT, 'data'), { recursive: true });
const out = {
← 2f74ee0 Safety-when-on: ARMED gate (no live post until SOCIAL_LIVE_A
·
back to Dw Marketing Reels
·
Dry-run publish status for cork reel: IG ready-pending-arm ( 808fac7 →